@@ -3,13 +3,14 @@ package HTML::FormBuilder;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Carp;
 use HTML::FormBuilder::FieldSet;
 use String::Random ();
 use Moo;
 use namespace::clean;
+use HTML::Entities;
 extends qw(HTML::FormBuilder::Base);
 
 has data => (
@@ -260,7 +261,7 @@ sub set_field_value {
                 # for select box
                 $_->value($field_value);
             } elsif ($_->{'type'} =~ /(?:text|textarea|password|hidden|file)/i) {
-                $_->{'value'} = $field_value;
+                $_->{'value'} = HTML::Entities::encode_entities($field_value // '');
             } elsif ($_->{'type'} eq 'checkbox') {
                 # if value not set during $fieldset->add_field(), default to browser default value for checkbox: 'on'
                 my $checkbox_value = $_->{'value'} // 'on';
@@ -293,9 +294,10 @@ sub get_field_value {
                 return $input->value;
             }
             return unless $input->{type};
-            if (   $input->{type} =~ /(?:text|textarea|password|hidden|file)/i
-                || $input->{type} eq 'checkbox' && $input->{checked} && $input->{checked} eq 'checked')
-            {
+
+            if ($input->{type} =~ /(?:text|textarea|password|hidden|file)/i) {
+                return HTML::Entities::decode_entities($input->{value} // '');
+            } elsif ($input->{type} eq 'checkbox' && $input->{checked} && $input->{checked} eq 'checked') {
                 # if value not set during $fieldset->add_field(), default to browser default value for checkbox: 'on'
                 return ($input->{value} // 'on');
             }
