@@ -3,7 +3,7 @@ package HTML::FormBuilder::Base;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Carp;
 use Moo;
@@ -130,6 +130,12 @@ please refer to L<HTML::FormBuilder>.
 
 Chylli L<chylli@binary.com>
 
+=head1 CONTRIBUTOR
+
+Fayland Lam L<fayland@binary.com>
+
+Tee Shuwn Yuan L<shuwnyuan@binary.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 =cut
